==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/cy/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Mae defnyddiwr wedi canslo cais am eitem ar y wefan',
    'a_user_requested' => 'Mae defnyddiwr wedi gwneud cais am eitem ar y wefan',
    'accessory_name' => 'Enw Ategolyn:',
    'additional_notes' => 'Nodiadau ychwanegol:',
    'admin_has_created' => 'Mae gweinyddwr wedi creu cyfrif i chi a yr :web wefan.',
    'asset' => 'Ased:',
    'asset_name' => 'Enw Ased:',
    'asset_requested' => 'Gofynnwyd am ased',
    'asset_tag' => 'Tag Ased:',
    'assigned_to' => 'Wedi Neilltuo i',
    'best_regards' => 'Cofon gorau,',
    'canceled' => 'Wedi canslo:',
    'checkin_date' => 'Dyddian i mewn:',
    'checkout_date' => 'Dyddiad Allan:',
    'click_to_confirm' => 'Cliciwch ar y ddolen ganlynol i gadarnhau eich cyfrif :gwe:',
    'click_on_the_link_accessory' => 'Cliciwch ar y ddolen ar y gwaelod i gadarnhau eich bod wedi derbyn yr ategolyn.',
    'click_on_the_link_asset' => 'Cliciwch ar y ddolen ar y gwaelod i gadarnhau eich bod wedi derbyn yr ased.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Nifer cyfredol',
    'Days' => 'Dyddiau',
    'days' => 'Dydd',
    'expecting_checkin_date' => 'Dyddiad disgwl i mewn:',
    'expires' => 'Dod i ben',
    'Expiring_Assets_Report' => 'Adroddiad Asedau sy\'n Dod i Ben.',
    'Expiring_Licenses_Report' => 'Adroddiad Trwyddedua sy\'n Dod i Ben.',
    'hello' => 'Helo',
    'hi' => 'Hi',
    'i_have_read' => 'Rwyf wedi darllen a chytuno â\'r telerau defnyddio, ac wedi derbyn yr eitem hon.',
    'item' => 'Eitem:',
    'Item_Request_Canceled' => 'Cais am eitem wedi canslo',
    'Item_Requested' => 'Wedi gwneud cais am eitem',
    'link_to_update_password' => 'Cliciwch ar y ddolen ganlynol i gadarnhau eich cyfrinair :gwe:',
    'login_first_admin' => 'Mewngofnodi i\'ch gosodiad Snipe-IT newydd gan ddefnyddio\'r manylion isod:',
    'login' => 'Mewngofnodi:',
    'Low_Inventory_Report' => 'Adroddiad Inventory Isel',
    'min_QTY' => 'Nifer Lleiaf',
    'name' => 'Enw',
    'new_item_checked' => 'Mae eitem newydd wedi\'i gwirio o dan eich enw, mae\'r manylion isod.',
    'password' => 'Cyfrinair:',
    'password_reset' => 'Ailosod Cyfrinair',

    'read_the_terms' => 'Darllenwch y telerau defnyddio isod.',
    'read_the_terms_and_click' => 'Darllenwch y telerau defnyddio isod, a chliciwch ar y ddolen ar y gwaelod i gadarnhau eich bod chi\'n darllen
                         a chytuno i\'r telerau defnyddio, ac wedi derbyn yr ased.',
    'requested' => 'Gofynnwyd amdano:',
    'reset_link' => 'Eich dolen Ail-osod Cyfrinair',
    'reset_password' => 'Cliciwch yma i ailosod eich cyfrinair:',
    'serial' => 'Serial',
    'supplier' => 'Cyflenwr',
    'tag' => 'Tag',
    'test_email' => 'Ebost prawf gan Snipe-IT',
    'test_mail_text' => 'Prawf yw hwn o\'r System Rheoli Asedau Snipe-IT. Os cawsoch chi hwn, mae\'r ebostyn gweithio :)',
    'the_following_item' => 'Mae\'r eitem yma wedi nodi i fewn: ',
    'low_inventory_alert' => 'Mae yna :count eitem sy\'n is na\'r isafswm neu a fydd yn isel cyn bo hir. | Mae yna :count eitemau sy\'n is na\'r isafswm neu a fydd yn isel cyn bo hir.',
    'assets_warrantee_alert' => 'Mae yna :count ased gyda gwarant yn dod i ben yn ystod y :threshold dydd nesaf | Mae :count asedau gyda gwarantau yn dod i ben yn y :threshold diwrnod nesaf.',
    'license_expiring_alert' => 'Mae yna :count trwydded yn dod i ben yn ystod y :threshold diwrnod nesaf | Mae :count trwyddedau yn dod i ben yn y :threshold diwrnod nesaf.',
    'to_reset' => 'I ailosod eich cyfrinair :web, cwblhewch y ffurflen hon:',
    'type' => 'Math',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Defnyddiwr',
    'username' => 'Enw defnyddiwr',
    'welcome' => 'Croeso, :name',
    'welcome_to' => 'Croeso i :web!',
    'your_credentials' => 'Eich manylion defnyddiwr Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/cy/mail.php <==
<?php

return [
    'a_user_canceled' => 'Mae defnyddiwr wedi canslo cais am eitem ar y wefan',
    'a_user_requested' => 'Mae defnyddiwr wedi gwneud cais am eitem ar y wefan',
    'accessory_name' => 'Enw Ategolyn:',
    'additional_notes' => 'Nodiadau ychwanegol:',
    'admin_has_created' => 'Mae gweinyddwr wedi creu cyfrif i chi a yr :web wefan.',
    'asset' => 'Ased:',
    'asset_name' => 'Enw Ased:',
    'asset_requested' => 'Gofynnwyd am ased',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'Wedi Neilltuo i',
    'best_regards' => 'Cofon gorau,',
    'canceled' => 'Wedi canslo:',
    'checkin_date' => 'Dyddian i mewn:',
    'checkout_date' => 'Dyddiad Allan:',
    'click_to_confirm' => 'Cliciwch ar y ddolen ganlynol i gadarnhau eich cyfrif :gwe:',
    'click_on_the_link_accessory' => 'Cliciwch ar y ddolen ar y gwaelod i gadarnhau eich bod wedi derbyn yr ategolyn.',
    'click_on_the_link_asset' => 'Cliciwch ar y ddolen ar y gwaelod i gadarnhau eich bod wedi derbyn yr ased.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Nifer cyfredol',
    'Days' => 'Dyddiau',
    'days' => 'Dydd',
    'expecting_checkin_date' => 'Dyddiad disgwl i mewn:',
    'expires' => 'Dod i ben',
    'Expiring_Assets_Report' => 'Adroddiad Asedau sy\'n Dod i Ben.',
    'Expiring_Licenses_Report' => 'Adroddiad Trwyddedua sy\'n Dod i Ben.',
    'hello' => 'Helo',
    'hi' => 'Hi',
    'i_have_read' => 'Rwyf wedi darllen a chytuno â\'r telerau defnyddio, ac wedi derbyn yr eitem hon.',
    'item' => 'Eitem:',
    'Item_Request_Canceled' => 'Cais am eitem wedi canslo',
    'Item_Requested' => 'Wedi gwneud cais am eitem',
    'link_to_update_password' => 'Cliciwch ar y ddolen ganlynol i gadarnhau eich cyfrinair :gwe:',
    'login_first_admin' => 'Mewngofnodi i\'ch gosodiad Snipe-IT newydd gan ddefnyddio\'r manylion isod:',
    'login' => 'Mewngofnodi:',
    'Low_Inventory_Report' => 'Adroddiad Inventory Isel',
    'min_QTY' => 'Nifer Lleiaf',
    'name' => 'Enw',
    'new_item_checked' => 'Mae eitem newydd wedi\'i gwirio o dan eich enw, mae\'r manylion isod.',
    'password' => 'Cyfrinair:',
    'password_reset' => 'Ailosod Cyfrinair',

    'read_the_terms' => 'Darllenwch y telerau defnyddio isod.',
    'read_the_terms_and_click' => 'Darllenwch y telerau defnyddio isod, a chliciwch ar y ddolen ar y gwaelod i gadarnhau eich bod chi\'n darllen
                         a chytuno i\'r telerau defnyddio, ac wedi derbyn yr ased.',
    'requested' => 'Gofynnwyd amdano:',
    'reset_link' => 'Eich dolen Ail-osod Cyfrinair',
    'reset_password' => 'Cliciwch yma i ailosod eich cyfrinair:',
    'serial' => 'Serial',
    'supplier' => 'Cyflenwr',
    'tag' => 'Tag',
    'test_email' => 'Ebost prawf gan Snipe-IT',
    'test_mail_text' => 'Prawf yw hwn o\'r System Rheoli Asedau Snipe-IT. Os cawsoch chi hwn, mae\'r ebostyn gweithio :)',
    'the_following_item' => 'Mae\'r eitem yma wedi nodi i fewn: ',
    'low_inventory_alert' => 'Mae yna :count eitem sy\'n is na\'r isafswm neu a fydd yn isel cyn bo hir. | Mae yna :count eitemau sy\'n is na\'r isafswm neu a fydd yn isel cyn bo hir.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'Mae yna :count trwydded yn dod i ben yn ystod y :threshold diwrnod nesaf | Mae :count trwyddedau yn dod i ben yn y :threshold diwrnod nesaf.',
    'to_reset' => 'I ailosod eich cyfrinair :web, cwblhewch y ffurflen hon:',
    'type' => 'Math',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Defnyddiwr',
    'username' => 'Enw defnyddiwr',
    'welcome' => 'Croeso, :name',
    'welcome_to' => 'Croeso i :web!',
    'your_credentials' => 'Eich manylion defnyddiwr Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
];
